#
# spec file for package exabgp
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} > 1210 || 0%{?rhel_version} > 6 || 0%{?centos_version} > 6 || 0%{?fedora_version} >= 20 || 0%{?el7}%{?fc20}%{?fc21}%{?fc22}
%bcond_without systemd
%else
%bcond_with    systemd
%endif
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Name:           exabgp
Version:        3.4.23
Release:        1.1
License:        BSD-3-Clause
Summary:        The BGP swiss army knife of networking
Url:            https://github.com/Exa-Networks/exabgp
Group:          Productivity/Networking/Routing
Source:         https://github.com/Exa-Networks/exabgp/archive/%{version}.tar.gz
Source2:	exabgp-suse.init
Patch100:	exabgp-3.4.20_OrderedDict.patch
BuildRequires:  python-devel
BuildRequires:  python-ipaddr
BuildRequires:  python-setuptools
Requires:       python-ipaddr
Requires:       python-setuptools
Requires:       python
PreReq:         python-%{name}
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
%if 0%{?suse_version}
Requires(pre):  %insserv_prereq
%endif
%endif
%if 0%{?suse_version}
Requires(pre):  %fillup_prereq
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#BuildArch:      noarch

%description
ExaBGP allows engineers to control their network from commodity servers. Think
of it as Software Defined Networking using BGP by transforming BGP messages
into friendly plain text or JSON.

It comes with an healthcheck application to help you monitor your daemons and
withdraw dead ones from the network during failures/maintenances. A full lab
explaining how to use it is available here.

Find what other users have done with it. Current documented use cases include
DDOS mitigation, network visualisation, anycast, service high availability.


%package -n python-%{name}
Group:          Development/Libraries/Python
#
Summary:        The BGP swiss army knife of networking
%description -n python-%{name}
ExaBGP allows engineers to control their network from commodity servers. Think
of it as Software Defined Networking using BGP by transforming BGP messages
into friendly plain text or JSON.

It comes with an healthcheck application to help you monitor your daemons and
withdraw dead ones from the network during failures/maintenances. A full lab
explaining how to use it is available here.

Find what other users have done with it. Current documented use cases include
DDOS mitigation, network visualisation, anycast, service high availability.

%prep
%setup -q
%patch100

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

mv %{buildroot}%{_bindir} %{buildroot}%{_sbindir}

install -d %{buildroot}%{_sysconfdir}/

install -D -m 0644 doc/man/exabgp.1      %{buildroot}%{_mandir}/man1/exabgp.1
install -D -m 0644 doc/man/exabgp.conf.5 %{buildroot}%{_mandir}/man5/exabgp.conf.5

%if %{with systemd}
install -D -m 0644 etc/systemd/exabgp.service %{buildroot}%{_unitdir}/exabgp.service
ln -s service %{buildroot}%{_sbindir}/rc%{name}
%else
%if 0%{?suse_version}
install -D -m755 %{S:2} %{buildroot}%{_sysconfdir}/init.d/exabgp
%endif
%endif

%if %{with systemd}
%if 0%{?suse_version}
%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service
%endif
%endif

%files
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%config(noreplace) %{_datadir}/%{name}%{_sysconfdir}
%{_datadir}/%{name}/processes
%if %{with systemd}
%{_sbindir}/rc%{name}
%{_unitdir}/exabgp.service
%else
%if 0%{?suse_version}
%attr(755, root, root) %{_sysconfdir}/init.d/exabgp
%endif
%endif
%{_mandir}/man1/exabgp.1*
%{_mandir}/man5/exabgp.conf.5*
%doc CHANGELOG COPYRIGHT PEP8 PYPI.rst README.md

%files -n python-%{name}
%defattr(-,root,root)
%{_sbindir}/%{name}
%{python_sitelib}/%{name}-%{version}*/
%{python_sitelib}/%{name}/
%changelog
* Fri Feb  9 2018 cs@linux-administrator.com
- update to Version 3.4.23
* Mon Jan 29 2018 cs@linux-administrator.com
- update to Version 3.4.21
    Fix: make healthcheck work on netbsd
    Fix: re-fix issue #493 Multiple IPv6 MPREACH attributes in one UPDATE
    Fix: issue #732 --test not working for eBGP setup
    Fix: possibly missing API message when sent at high rate, issue #736
* Mon Jul  3 2017 cs@linux-administrator.com
- update to Version 3.4.20
  * Fix: profiling
  * Fix: potential issue with networking (select on closed FD/TCP session)
  * Fix: issue with route replay order when sent fast
- Version 3.4.19
  * Add: IPv6 nlri-mpls to list of enabled protocol (was missing)
  * Fix: encoding of Flow Label requiring more than 2 bytes
  * Fix: decoding of capability (was potentially over reading)
  * Fix: trace when trying to access PID file and this is not allowed
  * Fix: Remove a peer's RIB cache when it is deleted from the config file
  * Fix: do not crash the reactor when an invalid IP is passed via the API
  * Fix: bad defintion of Flow for ICMPType, ICMPCode and Fragment
  * Feature: allow add-path for mpls-vpn
  * Change: Backported setup.py from master
  * Feature: added SRPMS for exabgp
* Wed Apr  5 2017 cs@linux-administrator.com
- update to Version 3.4.18
  * Backport: backhole community (RFC 7999) original patch by: Job Snijders
  * Fix: Configuration parser does not accept configs without neighbors. patch by doddt
  * Fix: 'connect' keyword is now also allowed in neighbor scope patch by: Stacey Sheldon (Corsa)
  * Fix: removing protocol auto-cleanup (it should never be called and seems to cause a CG issue) reported by: Colin Petrie
  * Change: default to a 0 offset for ipv6 flowspec source/destination match patch by: Brian Johnson
  * Fix: Better PID file handling reported by: Ben Agricola
  * Fix: Update RIB cache families on configuration reload patch by: Brian Johnson
  * Fix: Backport fix on SIGUSR2 (restarting process not needing to be) patch by: Shawn Zhou
  * Change: group-updates now generates one UPDATE per address family (and not one per NLRI for non IPv4) patch by: Brian Johnson
* Tue Sep 20 2016 cs@linux-administrator.com
- update to Version 3.4.17
  * Fix: does not accept IPv6 as router-id reported by: yuriya
  * Fix: JSON output for flow routes with rd reported by droon5
  * Fix: Fix Path-Information
  * Fix: Bad encoding of capability when multiple families are used for add-path reported: by Alexander Bespalov
  * Fix: support non ASN4 use of AS_TRANS (AS23456) reported by: Todd Crane
  * Fix: do not exit when we can not accept incoming connection reported by: Pavel Batkov
  * Fix: quote where not escaped in JSON reason field reported by: Rob Barnes
  * Fix: decoding of IPv6 flow routes reported by: stoffi92
  * Fix: decoding of Graceful Restart Capability patch by: florinz
  * Fix: ASN4 encoding patch by: Shu Sugimoto and Eiichiro Watanabe
  * Change: Run without even peers configured patch by: Jordan Gedney
  * Fix: JSON encoding of updates without NLRIs patch by: Dhammika Pathirana
  * Fix: Possible race conditions in api handling patch by: Brian Johnson
  * Feature: Add 'show neighbor status' api patch by: Brian Johnson
  * Fix: flush route api patch by: Brian Johnson
  * Fix: Allow asn4 peer to speak with asn2 only peer patch by: Brian Johnson
  * Fix: only one MP NLRI is allow per UPDATE reported by: subsecond
  * Change: configuration output does not includes ':' anymore patch by: doddt
  * Change: syslog format changed to be in line with other application patch by: Brian Johnson
* Tue Jun 28 2016 mardnh@gmx.de
- update to Version 3.4.16
  * Feature: allow users to decide if processes must be run before or after we
    drop privileges
  * Fix: correctly look in /etc/exabgp for programs to run when the path
    is relative
  * Fix: missing handler for NOTIFICATION
  Version 3.4.15
  * Fix: the ttl-security parameter didn´t really work. Fixed for outgoing
    connections now.
  * Fix: configuration leak between processes for neighbor-changes and
    send-packets
  * Feature: add per neighbor connection port
  * Fix: ASN4 boundary off by one
  * Fix: Bad peer IP when using show routes
  * Fix: Missing next-hop in the text api
  * Fix: broken route-refresh command
  * Fix: wrongly announcing connection issue with peer on the API
- change source url
* Sat Oct 17 2015 mrueckert@suse.de
- initial package
